==> NISP-2.2-2-src.zip: nisp/sci_gateway/cpp/sci_setrandvar_setsample.cpp <==

// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}

/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_SetRandomVariable_map.hxx" 


/* ==================================================================== */
// 
// setrandvar_setsample ( token , name , np ) 
//   initialize the number of simulation to np and stores the name of the sampling
// setrandvar_setsample ( token , k , i , value ) 
//   set the value of the the sample input #i with 1<= i<= nx where nx is the number 
//     of random variables of the sample #k with 1<= k<= np, where np is the number of simulations
// setrandvar_setsample ( token , k , value ) 
//   set the sample #k with 1<= k<= np, where np is the number of simulations 
//   and value is a matrix with size 1 x (nx)
// setrandvar_setsample ( token , value ) 
//   set the experiment matrix, where value is a matrix with size (np) x (nx)
//
int sci_setrandvar_setsample (char *fname)
{
	int nRows, nCols;
	int token;
	SetRandomVariable * srv = NULL;
	double * mydata = NULL;
	double value;
	int i, k;
	char * name = NULL;
	int np;
	string stringname;
	double * valueVector;
	int nx;

	CheckRhs(2,4) ;
	CheckLhs(0,1) ;
	nisp_gettoken ( fname , 1 , & token );
	if ( (Rhs == 4) ) {
		// setrandvar_setsample ( token , k , i , value ) 
		nisp_GetOneInteger ( fname , 2 , &k );
		nisp_GetOneInteger ( fname , 3 , &i );
		nisp_GetOneDouble ( fname , 4 , &value );
	} else if ( (Rhs == 3) ) {
		if ( GetType(2) == sci_strings )
		{
			// setrandvar_setsample ( token , name , np ) 
			nisp_GetOneChar ( fname , 2 , &name );
			nisp_GetOneInteger ( fname , 3 , &np );
		} else if ( GetType(2) == sci_matrix ) {
			// setrandvar_setsample ( token , k , value ) 
			nisp_GetOneInteger ( fname , 2 , &k );
			// Get value as valueVector
			nisp_AssertVarType(fname , 3 , sci_matrix );
			GetRhsVarMatrixDouble ( 3, &nRows, &nCols, &valueVector);
		} else {
			Scierror(204,_("%s: Wrong type for input argument #%d: String or double expected.\n"),fname,2);
			return 0;
		}
	} else if ( (Rhs == 2) ) {
		// setrandvar_setsample ( token , value ) 
		nisp_AssertVarType(fname , 2 , sci_matrix);
		GetRhsVarMatrixDouble ( 2, &nRows, &nCols, &valueVector);
	}
	// Get the set random variable
	nisp_token2Setrandvar ( fname , 1 , token , &srv );
	if ( (Rhs == 4) ) {
		srv->SetSample ( k , i , value );
	} else if ( (Rhs == 3) ) {
		if ( GetType(2) == sci_strings )
		{
			// setrandvar_setsample ( token , name , np ) 
			stringname.assign(name);
			srv->SetSample ( stringname , np );
		} else if ( GetType(2) == sci_matrix ) {
			// setrandvar_setsample ( token , k , value ) 
			nx = srv->GetDimension();
			// Check that input matrix has size 1 x (nx)
			nisp_AssertNRows ( fname , 3 , nRows , 1 );
			nisp_AssertNColumns ( fname , 3 , nCols , nx );
			for(int i=1;i<=nx;i++) {
				srv->SetSample(k, i, valueVector[i-1]);
			}
		}
	} else if ( (Rhs == 2) ) {
		// setrandvar_setsample ( token , value ) 
		// Check that input matrix has size np x (nx)
		nx = srv->GetDimension();
		np = srv->GetSize();
		nisp_AssertNRows ( fname , 2 , nRows , np );
		nisp_AssertNColumns ( fname , 2 , nCols , nx );
		for(int i=1;i<=nx;i++) {
			for(int k=1;k<=np;k++) {
				srv->SetSample(k, i, *(valueVector + (i-1) * np + (k-1)));
			}
		}
	}
	nisp_CreateLhsInteger ( 1 , token );
	return 0;
}
/* ==================================================================== */

==> NISP-2.4.1-1-src.zip: nisp/sci_gateway/cpp/sci_setrandvar_setsample.cpp <==

// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}

/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_SetRandomVariable_map.hxx" 


/* ==================================================================== */
// 
// setrandvar_setsample ( token , name , np ) 
//   initialize the number of simulation to np and stores the name of the sampling
// setrandvar_setsample ( token , k , i , value ) 
//   set the value of the the sample input #i with 1<= i<= nx where nx is the number 
//     of random variables of the sample #k with 1<= k<= np, where np is the number of simulations
// setrandvar_setsample ( token , k , value ) 
//   set the sample #k with 1<= k<= np, where np is the number of simulations 
//   and value is a matrix with size 1 x (nx)
// setrandvar_setsample ( token , value ) 
//   set the experiment matrix, where value is a matrix with size (np) x (nx)
//
int sci_setrandvar_setsample (char *fname)
{
	int nRows, nCols;
	int token;
	SetRandomVariable * srv = NULL;
	double * mydata = NULL;
	double value;
	int i, k;
	char * name = NULL;
	int np;
	double * valueVector;
	int nx;

	CheckRhs(2,4) ;
	CheckLhs(0,1) ;
	nispgw_gettoken ( fname , 1 , & token );
	if ( (Rhs == 4) ) {
		// setrandvar_setsample ( token , k , i , value ) 
		nispgw_GetOneInteger ( fname , 2 , &k );
		nispgw_GetOneInteger ( fname , 3 , &i );
		nispgw_GetOneDouble ( fname , 4 , &value );
	} else if ( (Rhs == 3) ) {
		if ( GetType(2) == sci_strings )
		{
			// setrandvar_setsample ( token , name , np ) 
			nispgw_GetOneChar ( fname , 2 , &name );
			nispgw_GetOneInteger ( fname , 3 , &np );
		} else if ( GetType(2) == sci_matrix ) {
			// setrandvar_setsample ( token , k , value ) 
			nispgw_GetOneInteger ( fname , 2 , &k );
			// Get value as valueVector
			nispgw_AssertVarType(fname , 3 , sci_matrix );
			GetRhsVarMatrixDouble ( 3, &nRows, &nCols, &valueVector);
		} else {
			Scierror(204,_("%s: Wrong type for input argument #%d: String or double expected.\n"),fname,2);
			return 0;
		}
	} else if ( (Rhs == 2) ) {
		// setrandvar_setsample ( token , value ) 
		nispgw_AssertVarType(fname , 2 , sci_matrix);
		GetRhsVarMatrixDouble ( 2, &nRows, &nCols, &valueVector);
	}
	// Get the set random variable
	nispgw_token2Setrandvar ( fname , 1 , token , &srv );
	if ( (Rhs == 4) ) {
		srv->SetSample ( k , i , value );
	} else if ( (Rhs == 3) ) {
		if ( GetType(2) == sci_strings )
		{
			srv->SetSample ( name , np );
		} else if ( GetType(2) == sci_matrix ) {
			nx = srv->GetDimension();
			// Check that input matrix has size 1 x (nx)
			nispgw_AssertNRows ( fname , 3 , nRows , 1 );
			nispgw_AssertNColumns ( fname , 3 , nCols , nx );
			for(int i=1;i<=nx;i++) {
				srv->SetSample(k, i, valueVector[i-1]);
			}
		}
	} else if ( (Rhs == 2) ) {
		// setrandvar_setsample ( token , value ) 
		// Check that input matrix has size np x (nx)
		nx = srv->GetDimension();
		np = srv->GetSize();
		nispgw_AssertNRows ( fname , 2 , nRows , np );
		nispgw_AssertNColumns ( fname , 2 , nCols , nx );
		for(int i=1;i<=nx;i++) {
			for(int k=1;k<=np;k++) {
				srv->SetSample(k, i, *(valueVector + (i-1) * np + (k-1)));
			}
		}
	}
	nispgw_CreateLhsInteger ( 1 , token );
	return 0;
}
/* ==================================================================== */
